==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder extends LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent<LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder> implements VisitableBuilder<LoadBalancerSettingsConsistentHashLBHttpCookieValue,LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder>{
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder() {
    this(false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder(Boolean validationEnabled) {
    this(new LoadBalancerSettingsConsistentHashLBHttpCookieValue(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder(LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent<?> fluent) {
    this(fluent, false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder(LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LoadBalancerSettingsConsistentHashLBHttpCookieValue(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder(LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent<?> fluent,LoadBalancerSettingsConsistentHashLBHttpCookieValue instance) {
    this(fluent, instance, false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder(LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent<?> fluent,LoadBalancerSettingsConsistentHashLBHttpCookieValue instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLBHttpCookieValue());

    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withPath(instance.getPath());
      fluent.withTtl(instance.getTtl());
      fluent.withName(instance.getName());
      fluent.withPath(instance.getPath());
      fluent.withTtl(instance.getTtl());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder(LoadBalancerSettingsConsistentHashLBHttpCookieValue instance) {
    this(instance,false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder(LoadBalancerSettingsConsistentHashLBHttpCookieValue instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLBHttpCookieValue());

    if (instance != null) {
      this.withName(instance.getName());
      this.withPath(instance.getPath());
      this.withTtl(instance.getTtl());
      this.withName(instance.getName());
      this.withPath(instance.getPath());
      this.withTtl(instance.getTtl());
    }
    this.validationEnabled = validationEnabled; 
  }
  LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent<?> fluent;
  Boolean validationEnabled;
  public LoadBalancerSettingsConsistentHashLBHttpCookieValue build() {
    LoadBalancerSettingsConsistentHashLBHttpCookieValue buildable = new LoadBalancerSettingsConsistentHashLBHttpCookieValue(fluent.getName(),fluent.getPath(),fluent.getTtl());
    return buildable;
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
public class LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder extends LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent<LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder> implements VisitableBuilder<LoadBalancerSettingsConsistentHashLBHttpCookieValue,LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder>{
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder() {
    this(new LoadBalancerSettingsConsistentHashLBHttpCookieValue());
  }
  
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder(LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent<?> fluent) {
    this(fluent, new LoadBalancerSettingsConsistentHashLBHttpCookieValue());
  }
  
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder(LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent<?> fluent,LoadBalancerSettingsConsistentHashLBHttpCookieValue instance) {
    this.fluent = fluent;
    fluent.copyInstance(instance);
  }
  
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder(LoadBalancerSettingsConsistentHashLBHttpCookieValue instance) {
    this.fluent = this;
    this.copyInstance(instance);
  }
  LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent<?> fluent;
  
  public LoadBalancerSettingsConsistentHashLBHttpCookieValue build() {
    LoadBalancerSettingsConsistentHashLBHttpCookieValue buildable = new LoadBalancerSettingsConsistentHashLBHttpCookieValue(fluent.getName(),fluent.getPath(),fluent.getTtl());
    return buildable;
  }
  

}
